==> PyGithub-1.53.tar.gz: PyGithub-1.53/tests/NamedUser1430.py <==
# -*- coding: utf-8 -*-

############################ Copyrights and license ############################
#                                                                              #
# Copyright 2020 Anuj Bansal <bansalanuj1996@gmail.com>                        #
#                                                                              #
# This file is part of PyGithub.                                               #
# http://pygithub.readthedocs.io/                                              #
#                                                                              #
# PyGithub is free software: you can redistribute it and/or modify it under    #
# the terms of the GNU Lesser General Public License as published by the Free  #
# Software Foundation, either version 3 of the License, or (at your option)    #
# any later version.                                                           #
#                                                                              #
# PyGithub is distributed in the hope that it will be useful, but WITHOUT ANY  #
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS    #
# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more #
# details.                                                                     #
#                                                                              #
# You should have received a copy of the GNU Lesser General Public License     #
# along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
#                                                                              #
################################################################################

from . import Framework


class NamedUser1430(Framework.TestCase):
    def setUp(self):
        super().setUp()
        self.user = self.g.get_user("ahhda")

    def testGetProjects(self):
        self.assertListKeyBegin(
            self.user.get_projects(state="all"), lambda e: e.id, [4083095],
        )

==> PyGithub-2.1.0.post0.tar.gz: PyGithub-2.1.0.post0/tests/NamedUser1430.py <==
############################ Copyrights and license ############################
#                                                                              #
# Copyright 2020 Anuj Bansal <bansalanuj1996@gmail.com>                        #
#                                                                              #
# This file is part of PyGithub.                                               #
# http://pygithub.readthedocs.io/                                              #
#                                                                              #
# PyGithub is free software: you can redistribute it and/or modify it under    #
# the terms of the GNU Lesser General Public License as published by the Free  #
# Software Foundation, either version 3 of the License, or (at your option)    #
# any later version.                                                           #
#                                                                              #
# PyGithub is distributed in the hope that it will be useful, but WITHOUT ANY  #
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS    #
# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more #
# details.                                                                     #
#                                                                              #
# You should have received a copy of the GNU Lesser General Public License     #
# along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
#                                                                              #
################################################################################

from . import Framework


class NamedUser1430(Framework.TestCase):
    def setUp(self):
        super().setUp()
        self.user = self.g.get_user("ahhda")

    def testGetProjects(self):
        self.assertListKeyBegin(
            self.user.get_projects(state="all"),
            lambda e: e.id,
            [4083095],
        )
